﻿#region Using directives

using System;
using System.ComponentModel;
using System.Collections.Generic;
using System.Diagnostics;
using System.Text;
using System.Windows.Forms;

#endregion

namespace AlarmComponentSample {

  [DesignerAttribute(typeof(HostComponentDesigner))]
  public partial class AlarmComponent : Component {

    DateTime alarm = DateTime.MaxValue; // No alarm

    public AlarmComponent() {
      InitializeComponent();
    }

    public AlarmComponent(IContainer container) {
      container.Add(this);
      InitializeComponent();
    }

    public DateTime Alarm {
      get { return this.alarm; }
      set { this.alarm = value; }
    }

    public DateTime DelayAlarm(double minutes) {
      if( this.alarm < DateTime.MaxValue ) {
        this.alarm = this.alarm.AddMinutes(minutes);
      }
      return this.alarm;
    }

    //public event EventHandler AlarmSounded;
    public event AlarmSoundedEventHandler AlarmSounded;

    // Hide from Properties Window and persist any value 
    // to container’s InitializeComponent
    ContainerControl host;
    [BrowsableAttribute(false)]
    [DefaultValueAttribute(null)]
    public ContainerControl Host {
      get { return this.host; }
      set { this.host = value; }
    }

    private void timer_Tick(object sender, System.EventArgs e) {
      // Check to see whether we're within 1 second of the alarm
      double seconds = (DateTime.Now - this.alarm).TotalSeconds;
      if( (seconds >= 0) && (seconds <= 1) ) {
        DateTime alarm = this.alarm;
        this.alarm = DateTime.MaxValue; // Show alarm only once
        if( this.AlarmSounded != null ) {
          AlarmSounded(this, new AlarmSoundedEventArgs(alarm));
        }
        else {
          // If no handlers, display a message box
          MessageBox.Show("Wake up!", this.host.Text);
        }
      }
    }
  }
}
