using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Text.RegularExpressions;
using System.Windows.Forms;

namespace ComponentSurveySample {
  public partial class UserInformationForm : Form {
    public UserInformationForm() {
      InitializeComponent();
      
      // Set help for Applicant Name text box
      this.helpProvider.SetHelpString(this.applicantNameTextBox, "Please enter a name");
      this.helpProvider.SetShowHelp(this.applicantNameTextBox, true);

      // Set help for Applicant Phone Number text box
      this.helpProvider.SetHelpString(this.applicantPhoneNoTextBox, "Please enter an Australian phone number: (xx) xxxx-xxxx");
      this.helpProvider.SetShowHelp(this.applicantPhoneNoTextBox, true);

      // Set help for Applicant Loan Amount text box
      this.helpProvider.SetHelpString(this.applicantLoanAmountTextBox, "Please enter a valid loan amount: x.xx");
      this.helpProvider.SetShowHelp(this.applicantLoanAmountTextBox, true);
      
      // Set tool tip for Applicant Name text box
      this.toolTip.SetToolTip(this.applicantNameTextBox, "Please enter a name");

      // Set tool tip for Applicant Phone Number text box
      this.toolTip.SetToolTip(this.applicantPhoneNoTextBox, "Please enter an Australian phone number: (xx) xxxx-xxxx");

      // Set tool tip for Applicant Loan Amount text box
      this.toolTip.SetToolTip(this.applicantLoanAmountTextBox, "Please enter a valid loan amount: x.xx");
      
      // Show notify icon with balloon-style tool tip
      this.notifyIcon.Icon = Properties.Resources.Butterfly;
      this.notifyIcon.BalloonTipText = "Float like a butterfly, ...";
      this.notifyIcon.ShowBalloonTip(5000);
    }

    private void applicantNameTextBox_Validating(object sender, CancelEventArgs e) {
      // Check that applicant name exists
      if( ((TextBox)sender).Text.Trim() == "" ) {
        // Show error
        this.errorProvider.SetError((TextBox)sender, "Please enter a name");
        e.Cancel = true;
      }
      else {
        // Hide error
        this.errorProvider.SetError((TextBox)sender, null);
      }
    }

    private void applicantPhoneNoTextBox_Validating(object sender, CancelEventArgs e) {
      Regex rgxOzPhone = new Regex(@"^\(\d{2}\) \d{4}-\d{4}$");
      string error = null;
      // Check that a valid Australian application phone exists
      if( !rgxOzPhone.IsMatch(((TextBox)sender).Text) ) {
        error = "Please enter an Australian phone number: (xx) xxxx-xxxx";
        e.Cancel = true;
      }
      this.errorProvider.SetError((TextBox)sender, error);
    }

    private void applicantLoanAmountTextBox_Validating(object sender, CancelEventArgs e) {
      Regex rgxLoanAmount = new Regex(@"^\d{1,}.\d{2}$");
      string error = null;
      // Check that a valid applicant loan amount was provided
      if( !rgxLoanAmount.IsMatch(((TextBox)sender).Text) ) {
        error = "Please enter a valid loan amount: x.xx";
        e.Cancel = true;
      }
      this.errorProvider.SetError((TextBox)sender, error);
    }
  }
}